pub struct LruModelCache<T> { /* private fields */ }Expand description
LRU (Least Recently Used) cache for model elements
Thread-safe cache with automatic eviction of least recently used items.
Implementations
Sourceimpl<T> LruModelCache<T>where
T: Clone,
impl<T> LruModelCache<T>where
T: Clone,
Sourcepub fn get(&self, key: &str) -> Option<Arc<T>>
pub fn get(&self, key: &str) -> Option<Arc<T>>
Get an item from the cache
Updates access statistics and LRU ordering.
Sourcepub fn put(&mut self, key: String, value: Arc<T>)
pub fn put(&mut self, key: String, value: Arc<T>)
Put an item into the cache
If the cache is at capacity, evicts the least recently used item.
Sourcepub fn resize(&mut self, new_capacity: usize)
pub fn resize(&mut self, new_capacity: usize)
Resize the cache capacity
If the new capacity is smaller than current size, evicts LRU items.
Sourcepub fn reset_statistics(&mut self)
pub fn reset_statistics(&mut self)
Reset cache statistics
Sourcepub fn statistics(&self) -> CacheStatistics
pub fn statistics(&self) -> CacheStatistics
Get cache statistics